@@ -105,6 +105,15 @@ class ButtonBlock(LinkBlock):
         label = "Button"
 
 
+class IconTextBlock(blocks.StructBlock):
+    icon = SnippetChooserBlock('cms.IconSnippet', required=True)
+    text = TextBlock()
+
+    class Meta:
+        template = '%s/common/icon_text.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Icon Text"
+
+
 class FormBlock(blocks.StructBlock):
     form = SnippetChooserBlock('cms.Form', required=True)
 
@@ -125,7 +134,7 @@ class PersonBlock(blocks.StructBlock):
     person = SnippetChooserBlock('cms.Person', required=True)
 
     class Meta:
-        template = '%s/common/person.html' % constants.BLOCK_TEMPLATES_PATH
+        template = '%s/common/cards/person.html' % constants.BLOCK_TEMPLATES_PATH
         label = "Person"
 
 
