@@ -21,4 +21,4 @@ class GalleryEntry(EntryBlock):
 
     class Meta:
         template = '%s/entries/gallery.html' % constants.BLOCK_TEMPLATES_PATH
-        label = "Form"
+        label = "Gallery"
