@@ -3,6 +3,7 @@ import requests
 import logging
 
 from django import template
+from django.conf import settings
 from wagtail.embeds.embeds import get_embed
 from wagtail.embeds.exceptions import EmbedException
 
@@ -98,7 +99,7 @@ class AMPStyles(template.Node):
             tree = etree.XML(html)
             href = tree.get('href')
             request = context['request']
-            http = 'https://' if request.is_secure() else 'http://'
+            http = 'https://' if not settings.DEBUG else 'http://'
             host = request.site.hostname
             if host == 'localhost':
                 host += ':8080'
@@ -106,7 +107,7 @@ class AMPStyles(template.Node):
             logger.debug(url)
             response = requests.get(url)
             css = response.content.decode().replace('\n', '').replace('!important', '')
-            ret = "<style amp-custom>%s</style>" % url
+            ret = "<style amp-custom>%s</style>" % css
             return ret
         return self.nodelist.render(context)
 
@@ -174,5 +175,9 @@ def amp_embed(url):
 
         return ret
     except EmbedException:
-        # Cannot find embed
-        pass
+        return "<amp-iframe " \
+               "width='480' " \
+               "height='270' " \
+               "sandbox='allow-scripts allow-same-origin allow-presentation' " \
+               "layout='responsive' " \
+               "src='%s'></amp-iframe>" % url
